@@ -2,16 +2,15 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from .party import *
-from .sale import *
-from . import configuration
+
+from . import configuration, party, sale
 
 
 def register():
     Pool.register(
-        Party,
-        PartySaleShipmentGroupingMethod,
-        Sale,
+        party.Party,
+        party.PartySaleShipmentGroupingMethod,
+        sale.Sale,
         configuration.Configuration,
         configuration.ConfigurationSaleMethod,
         module='sale_shipment_grouping', type_='model')
